import _extends from 'babel-runtime/helpers/extends';
import React from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';
import { ActivityButton, CallControl } from '@collab-ui/react';

var styles = {
  'controlContainer': 'controlContainer--1zPXQ',
  'controlItem': 'controlItem--Jb6Vr',
  'button': 'button--146DH'
}; // @related-file ./styles.css

const propTypes = {
  buttons: PropTypes.arrayOf(PropTypes.shape({
    accessibilityLabel: PropTypes.string,
    label: PropTypes.string,
    buttonClassName: PropTypes.string,
    buttonType: PropTypes.oneOfType([PropTypes.oneOf(['chat', 'camera', 'meetings', 'whiteboard', 'files', 'share-screen', 'tasks', 'microphone-muted', 'camera-muted', 'cancel']), PropTypes.shape({
      color: PropTypes.string,
      icon: PropTypes.element.isRequired
    })]),
    callControl: PropTypes.bool,
    onClick: PropTypes.func
  })).isRequired,
  showLabels: PropTypes.bool

};

const defaultProps = {
  showLabels: false
};

function ButtonControls(props) {
  const {
    buttons,
    showLabels
  } = props;

  const buttonsRendered = buttons.map(button => {
    const label = showLabels && button.label ? button.label : '';

    if (button.callControl) {
      return React.createElement(CallControl, _extends({}, button, {
        label: label,
        ariaLabel: button.accessibilityLabel || button.label,
        type: button.buttonType
      }));
    }

    return React.createElement(ActivityButton, _extends({}, button, {
      label: label,
      ariaLabel: button.accessibilityLabel || button.label,
      type: button.buttonType
    }));
  });

  return React.createElement(
    'div',
    { className: classNames('ciscospark-controls-container', styles.controlContainer) },
    buttonsRendered
  );
}

ButtonControls.propTypes = propTypes;
ButtonControls.defaultProps = defaultProps;

export default ButtonControls;